#!/bin/perl
#################################################################################
# Created       : Martin Foster
# Modified      : 19-May-2003
#################################################################################
#
# Bio - Script part of Ethereal Realms designed to show a puppet/puppeteer bio 
# Copyright (C) 2000-2003  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 204 - 817, 5th Street NE
#                 Calgary, Alberta
#                 T2E 3W9
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use eRealms::Database;						# Database handler
use eRealms::Param;						# Parameter control
use eRealms::Table;						# Table handler	
use eRealms::Template;						# Template handler


#################################################################################
# Data Members
#################################################################################
my $cgi;							# Common gateway interface handle
my $database;							# Database handle
my $param;							# Parameter handle
my $table;							# Table handle
my $tmpl;							# Template handle

my $res;							# Result handle
my $statement;							# Query

my $bio;							# Bio Link
my $display;							# Display contact
my $type;							# Parameter type
my $url;							# Link

my %config;							# Configuration hash


#################################################################################
# Program Area
#################################################################################

	# Initial handles
	$cgi      = new CGI;
	$database = new eRealms::Database();

	# Connect and Fetch
	$database->Connect();

	# Parameter handling
	$param = new eRealms::Param($database, $cgi);
	$param->GetParam();

	# Link with hash
	$database->GetHashConfiguration(\%config);

	
	# Initialize handles
	$table    = new eRealms::Table($cgi);
	$tmpl     = new eRealms::Template(\%config);


	# Document header
	print $cgi->header();
	$database->DocumentGetHeader();


	# Information must exist
	if (defined($param->{'USER'}))
	{
		# Pull information
		# Puppet specific homepage
		($bio, $display) = $database->DataGet("SELECT PuppetBio, PuppetDisplay
			FROM  Puppet
			WHERE PuppetName=?
			  AND PuppeteerLogin=?", 
	
		 $param->{'CHAR'},
		 $param->{'USER'});


		# Puppet specific
		if (defined($bio))
		{
			# Title display
			$tmpl->ShowMain($config{'TagContactPuppet'});

			# Table display
			$table->MakeTop();
			$table->MakeBlank();
			$table->MakeValid("<B>$config{'TxtContact'}</B>", "<A HREF=\"$bio\">$bio</A>");
			$table->MakeBottom();
		}


		# Run through and display
		# Prepare and execute
		$database->Pull(\$statement, "SELECT 
			  c.ContactName   AS \"Name\", 
			  c.ContactFilter AS \"Filter\", 
			  c.ContactType   AS \"Type\", 
			  d.ContactData   AS \"Data\"
			FROM 
			  Contact c,
			  PuppeteerContact d
			WHERE d.ContactName = c.ContactName
			  AND d.PuppeteerLogin=?
			ORDER BY c.ContactType, c.ContactName",

		 $param->{'USER'}
		);


		# Initial retrieval
		$res  = $statement->fetchrow_hashref();
		$type = 'None';

		# Only display if need
		if ((defined($res)) && ($display eq 'yes'))
		{
			# Spacer
			print "<BR>\n<BR>\n<BR>\n";

			# Title display
			$tmpl->ShowMain($config{'TagContactPuppeteer'});

			# Table top
			$table->MakeTop();


			# Single run
			# Type handle
			$type = CheckType($res->{'Type'}, $type, $config{'TmplSub'});

			# Display row
			ContentDisplay($table, $res->{'Filter'}, $res->{'Type'}, $res->{'Name'}, $res->{'Data'});


			# Possibly loop
			while ($res = $statement->fetchrow_hashref())
			{
				# Looped operation
				# Type handler
				$type = CheckType($res->{'Type'}, $type, $config{'TmplSub'});

				# Display row
				ContentDisplay($table, $res->{'Filter'}, $res->{'Type'}, $res->{'Name'}, $res->{'Data'});
			}	

			# End of table
			$table->MakeBottom();	
		}

		# Default messages
		else
		{
			# Spacer
			print "<BR>\n<BR>\n<BR>\n";

			# Title display
			$tmpl->ShowMain($config{'TagContactPuppeteer'});

			# Table top
			$table->MakeTop();

			# Message display
			$table->MakeBlank();
			$table->MakeSingle($config{'MsgContact'});

			# Message bottom
			$table->MakeBottom();
		}


		# End query
		$statement->finish();
	}

	# Document footer
	$database->DocumentGetFooter();

#################################################################################
# Sub-Routines
#################################################################################

#####################
# Type checks
#
# Will display titles if need be.   This is needed since the loop is a bit
# different then with other Contact scripts.

sub CheckType
{
	#####################
	# Data members
	my $check = shift;					# Value to check
	my $type  = shift;					# Mainstay type
	my $title = shift;					# Title to display


	#####################
	# Program area

	# Type display
	# Ensure assignment
	$check = (defined($check)) ? $check : 'None';

	# Determine need
	if (ucfirst($check) ne $type)
	{
		# Assign type
		$type = ucfirst($check);

		# Set title
		$title =~ s/MTITLE/$type/gs;

		# Display
		$table->MakeBlank();
		$table->MakeSingle($title);
	}

	# Return
	return $type;
}

#####################
# Content display
#
# Will display the contents of the variables.  Once it determines if there
# is a need to create links or some such.

sub ContentDisplay
{
	#####################
	# Data members
	my $table  = shift;					# Table handle
	my $filter = shift;					# Filter rule
	my $type   = shift;					# Type of information
	my $name   = shift;					# Name of info
	my $data   = shift;					# Information to process


	#####################
	# Program area

	# Email address
	if ($filter eq 'email')
	{
		# Create mail link
		$table->MakeValid("<B>$name</B>", "<A HREF=\"mailto:$data\">$data</A>"); 
	}

	# Standard URL
	elsif ($filter eq 'http')
	{
		# Just link and display
		if ($type ne 'picture')
		{
			# Create hyperlink
			$table->MakeValid("<B>$name</B>", "<A HREF=\"$data\" TARGET=\"_new\">$data</A>"); 
		}

		# Show picture
		else
		{
			# Show image
			$table->MakeValid("<B>$name</B>", "<IMG SRC=\"$data\" ALT=\"$name\">");
		}
	}

	# All other types
	else
	{
		# Simply display
		$table->MakeValid("<B>$name</B>", $data); 
	}
}
